@@ -1,20 +1,27 @@
 #!/usr/bin/env python3
-import argparse
-import os
 import sys
 
-from ucca.ioutil import file2passage, passage2file
+import argparse
+import os
+from tqdm import tqdm
+
+from ucca.ioutil import file2passage, passage2file, external_write_mode
 
 desc = """Parses an XML in UCCA standard format, and writes them in binary Pickle format."""
 
 
 def main(args):
-    for filename in args.filenames:
-        print("Reading passage '%s'..." % filename, file=sys.stderr)
+    os.makedirs(args.outdir, exist_ok=True)
+    for filename in tqdm(args.filenames, desc="Converting", unit=" passages"):
+        if args.verbose:
+            with external_write_mode():
+                print("Reading passage '%s'..." % filename, file=sys.stderr)
         passage = file2passage(filename)
         basename = os.path.splitext(os.path.basename(filename))[0]
         outfile = args.outdir + os.path.sep + basename + ".pickle"
-        print("Writing file '%s'..." % outfile, file=sys.stderr)
+        if args.verbose:
+            with external_write_mode():
+                print("Writing file '%s'..." % outfile, file=sys.stderr)
         passage2file(passage, outfile, binary=True)
 
 
@@ -22,4 +29,5 @@ if __name__ == '__main__':
     argparser = argparse.ArgumentParser(description=desc)
     argparser.add_argument('filenames', nargs='+', help="XML file names to convert")
     argparser.add_argument('-o', '--outdir', default='.', help="output directory")
+    argparser.add_argument('-v', '--verbose', action="store_true", help="verbose output")
     main(argparser.parse_args())
